import 'dart:async';

import 'package:flutter/services.dart';

class FlutterXNfc {
  static const MethodChannel _channel =
      const MethodChannel('flutter_x_nfc');

  static const stream =
  const EventChannel('flutter_x_nfc/event_channel');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Stream<NfcData> get read{
    final resultStream = _channel
        .invokeMethod('NfcRead')
        .asStream()
        .asyncExpand((_) => stream
        .receiveBroadcastStream()
        .map((result) => NfcData.fromMap(result)));
    return resultStream;
  }

  static Future<NfcData> get stop async {
    final Map data = await _channel.invokeMethod('NfcStop');

    final NfcData result = NfcData.fromMap(data);

    return result;
  }
}

class NfcData {
  final String id;
  final String message;

  NfcData({
    this.id,
    this.message
  });

  factory NfcData.fromMap(Map data) {
    if(data==null)
      return null;

    NfcData result = NfcData(
      id: data['id'],
      message: data['message'],
    );
    return result;
  }
}
